# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

from .function_call_option import FunctionCallOption

__all__ = ["NamedToolChoice"]


class NamedToolChoice(TypedDict, total=False):
    function: Optional[FunctionCallOption]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .browserbase_setup import BrowserbaseSetup
from .browserbase_create_session_arguments import BrowserbaseCreateSessionArguments

__all__ = ["BrowserbaseCreateSessionIntegrationDef"]


class BrowserbaseCreateSessionIntegrationDef(BaseModel):
    arguments: Optional[BrowserbaseCreateSessionArguments] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[BrowserbaseSetup] = None
    """The setup parameters for the browserbase integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import TYPE_CHECKING, Union, Optional
from typing_extensions import Literal, TypeAlias, TypeAliasType

from pydantic import Field as FieldInfo

from ..._compat import PYDANTIC_V2
from ..._models import BaseModel
from ..get_step import GetStep
from ..log_step import LogStep
from ..set_step import SetStep
from ..sleep_step import SleepStep
from ..yield_step import YieldStep
from ..return_step import ReturnStep
from ..evaluate_step import EvaluateStep
from ..tool_call_step import ToolCallStep
from ..prompt_step_output import PromptStepOutput
from ..switch_step_output import SwitchStepOutput
from ..error_workflow_step import ErrorWorkflowStep
from ..foreach_step_output import ForeachStepOutput
from ..wait_for_input_step import WaitForInputStep
from ..parallel_step_output import ParallelStepOutput

__all__ = [
    "IfElseStepOutput",
    "Then",
    "ThenThenOutput",
    "ThenThenOutputMap",
    "Else",
    "ElseElseOutput",
    "ElseElseOutputMap",
]

ThenThenOutputMap: TypeAlias = Union[EvaluateStep, ToolCallStep, PromptStepOutput, GetStep, SetStep, LogStep, YieldStep]


class ThenThenOutput(BaseModel):
    map: ThenThenOutputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


if TYPE_CHECKING or PYDANTIC_V2:
    Then = TypeAliasType(
        "Then",
        Union[
            WaitForInputStep,
            EvaluateStep,
            ToolCallStep,
            PromptStepOutput,
            GetStep,
            SetStep,
            LogStep,
            YieldStep,
            ReturnStep,
            SleepStep,
            ErrorWorkflowStep,
            "IfElseStepOutput",
            SwitchStepOutput,
            ForeachStepOutput,
            ParallelStepOutput,
            ThenThenOutput,
        ],
    )
else:
    Then: TypeAlias = Union[
        WaitForInputStep,
        EvaluateStep,
        ToolCallStep,
        PromptStepOutput,
        GetStep,
        SetStep,
        LogStep,
        YieldStep,
        ReturnStep,
        SleepStep,
        ErrorWorkflowStep,
        "IfElseStepOutput",
        SwitchStepOutput,
        ForeachStepOutput,
        ParallelStepOutput,
        ThenThenOutput,
    ]

ElseElseOutputMap: TypeAlias = Union[EvaluateStep, ToolCallStep, PromptStepOutput, GetStep, SetStep, LogStep, YieldStep]


class ElseElseOutput(BaseModel):
    map: ElseElseOutputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


if TYPE_CHECKING or PYDANTIC_V2:
    Else = TypeAliasType(
        "Else",
        Union[
            WaitForInputStep,
            EvaluateStep,
            ToolCallStep,
            PromptStepOutput,
            GetStep,
            SetStep,
            LogStep,
            YieldStep,
            ReturnStep,
            SleepStep,
            ErrorWorkflowStep,
            "IfElseStepOutput",
            SwitchStepOutput,
            ForeachStepOutput,
            ParallelStepOutput,
            ElseElseOutput,
            None,
        ],
    )
else:
    Else: TypeAlias = Union[
        WaitForInputStep,
        EvaluateStep,
        ToolCallStep,
        PromptStepOutput,
        GetStep,
        SetStep,
        LogStep,
        YieldStep,
        ReturnStep,
        SleepStep,
        ErrorWorkflowStep,
        "IfElseStepOutput",
        SwitchStepOutput,
        ForeachStepOutput,
        ParallelStepOutput,
        ElseElseOutput,
        None,
    ]


class IfElseStepOutput(BaseModel):
    if_: str = FieldInfo(alias="if")

    then: Then
    """The steps to run if the condition is true"""

    else_: Optional[Else] = FieldInfo(alias="else", default=None)
    """The steps to run if the condition is false"""

    kind: Optional[Literal["if_else"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


if PYDANTIC_V2:
    IfElseStepOutput.model_rebuild()
    ThenThenOutput.model_rebuild()
    ElseElseOutput.model_rebuild()
else:
    IfElseStepOutput.update_forward_refs()  # type: ignore
    ThenThenOutput.update_forward_refs()  # type: ignore
    ElseElseOutput.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel
from .hybrid_doc_search import HybridDocSearch
from .vector_doc_search import VectorDocSearch
from .text_only_doc_search import TextOnlyDocSearch

__all__ = ["Session", "RecallOptions"]

RecallOptions: TypeAlias = Union[VectorDocSearch, TextOnlyDocSearch, HybridDocSearch, None]


class Session(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    auto_run_tools: Optional[bool] = None

    context_overflow: Optional[Literal["truncate", "adaptive"]] = None

    forward_tool_calls: Optional[bool] = None

    kind: Optional[str] = None

    metadata: Optional[object] = None

    recall_options: Optional[RecallOptions] = None

    render_templates: Optional[bool] = None

    situation: Optional[str] = None

    summary: Optional[str] = None

    system_template: Optional[str] = None

    token_budget: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["BrowserbaseSetupUpdateParam"]


class BrowserbaseSetupUpdateParam(TypedDict, total=False):
    api_key: Optional[str]

    api_url: Optional[str]

    connect_url: Optional[str]

    project_id: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["CloudinarySetup"]


class CloudinarySetup(BaseModel):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["CloudinaryUploadArguments"]


class CloudinaryUploadArguments(TypedDict, total=False):
    file: Required[str]

    public_id: Optional[str]

    return_base64: bool

    upload_params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SleepFor"]


class SleepFor(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["ChosenBash20241022"]


class ChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ChosenComputer20241022"]


class ChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["DummyIntegrationDef"]


class DummyIntegrationDef(BaseModel):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .weather_setup import WeatherSetup
from .weather_get_arguments import WeatherGetArguments

__all__ = ["WeatherIntegrationDef"]


class WeatherIntegrationDef(TypedDict, total=False):
    arguments: Optional[WeatherGetArguments]
    """Arguments for Weather"""

    method: Optional[str]

    provider: Literal["weather"]

    setup: Optional[WeatherSetup]
    """Integration definition for Weather"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .cloudinary_setup import CloudinarySetup
from .cloudinary_edit_arguments import CloudinaryEditArguments

__all__ = ["CloudinaryEditIntegrationDef"]


class CloudinaryEditIntegrationDef(TypedDict, total=False):
    arguments: Optional[CloudinaryEditArguments]
    """Arguments for Cloudinary media edit"""

    method: Literal["media_edit"]

    provider: Literal["cloudinary"]

    setup: Optional[CloudinarySetup]
    """Setup parameters for Cloudinary integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .spider_setup import SpiderSetup
from .spider_fetch_arguments import SpiderFetchArguments

__all__ = ["SpiderIntegrationDef"]


class SpiderIntegrationDef(TypedDict, total=False):
    arguments: Optional[SpiderFetchArguments]
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]]

    provider: Literal["spider"]

    setup: Optional[SpiderSetup]
    """Setup parameters for Spider integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .wikipedia_search_arguments import WikipediaSearchArguments

__all__ = ["WikipediaIntegrationDef"]


class WikipediaIntegrationDef(TypedDict, total=False):
    arguments: Optional[WikipediaSearchArguments]
    """Arguments for Wikipedia Search"""

    method: Optional[str]

    provider: Literal["wikipedia"]

    setup: object



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["BrowserbaseSetup"]


class BrowserbaseSetup(TypedDict, total=False):
    api_key: Required[str]

    project_id: Required[str]

    api_url: Optional[str]

    connect_url: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["WeatherGetArguments"]


class WeatherGetArguments(BaseModel):
    location: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["TextEditor20241022Def"]


class TextEditor20241022Def(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..snippet import Snippet
from ..._models import BaseModel
from .doc_owner import DocOwner

__all__ = ["DocReference"]


class DocReference(BaseModel):
    id: str

    owner: DocOwner

    snippet: Snippet

    distance: Optional[float] = None

    metadata: Optional[object] = None

    title: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["BrowserbaseCompleteSessionArguments"]


class BrowserbaseCompleteSessionArguments(BaseModel):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .wait_for_input_info import WaitForInputInfo

__all__ = ["WaitForInputStep"]


class WaitForInputStep(BaseModel):
    wait_for_input: WaitForInputInfo

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["UnstructuredSetup"]


class UnstructuredSetup(TypedDict, total=False):
    unstructured_api_key: Required[str]

    retry_config: Optional[object]

    server: Optional[str]

    server_url: Optional[str]

    timeout_ms: Optional[int]

    url_params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional
from typing_extensions import Required, TypedDict

__all__ = ["LlamaParseFetchArguments"]


class LlamaParseFetchArguments(TypedDict, total=False):
    file: Required[Union[str, List[str]]]

    base64: bool

    filename: Optional[str]

    params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import TypedDict

__all__ = ["ReturnStepParam"]

_ReturnStepParamReservedKeywords = TypedDict(
    "_ReturnStepParamReservedKeywords",
    {
        "return": Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]],
    },
    total=False,
)


class ReturnStepParam(_ReturnStepParamReservedKeywords, total=False):
    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["BrowserbaseSetup"]


class BrowserbaseSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .get_step import GetStep
from .log_step import LogStep
from .set_step import SetStep
from .yield_step import YieldStep
from .evaluate_step import EvaluateStep
from .tool_call_step import ToolCallStep
from .prompt_step_output import PromptStepOutput

__all__ = ["ParallelStepOutput", "Parallel"]

Parallel: TypeAlias = Union[EvaluateStep, ToolCallStep, PromptStepOutput, GetStep, SetStep, LogStep, YieldStep]


class ParallelStepOutput(BaseModel):
    parallel: List[Parallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["ChosenBash20241022Param"]


class ChosenBash20241022Param(TypedDict, total=False):
    command: Optional[str]

    restart: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.secret_ref import SecretRef
from .shared.system_def import SystemDef
from .chosen_bash20241022 import ChosenBash20241022
from .shared.function_def import FunctionDef
from .chosen_function_call import ChosenFunctionCall
from .shared.doc_reference import DocReference
from .chosen_computer20241022 import ChosenComputer20241022
from .shared.bash20241022_def import Bash20241022Def
from .shared.named_tool_choice import NamedToolChoice
from .chosen_text_editor20241022 import ChosenTextEditor20241022
from .shared.computer20241022_def import Computer20241022Def
from .shared.arxiv_integration_def import ArxivIntegrationDef
from .shared.brave_integration_def import BraveIntegrationDef
from .shared.dummy_integration_def import DummyIntegrationDef
from .shared.email_integration_def import EmailIntegrationDef
from .shared.ffmpeg_integration_def import FfmpegIntegrationDef
from .shared.spider_integration_def import SpiderIntegrationDef
from .shared.algolia_integration_def import AlgoliaIntegrationDef
from .shared.mailgun_integration_def import MailgunIntegrationDef
from .shared.text_editor20241022_def import TextEditor20241022Def
from .shared.weather_integration_def import WeatherIntegrationDef
from .shared.wikipedia_integration_def import WikipediaIntegrationDef
from .shared.llama_parse_integration_def import LlamaParseIntegrationDef
from .shared.unstructured_integration_def import UnstructuredIntegrationDef
from .shared.remote_browser_integration_def import RemoteBrowserIntegrationDef
from .shared.cloudinary_edit_integration_def import CloudinaryEditIntegrationDef
from .shared.cloudinary_upload_integration_def import CloudinaryUploadIntegrationDef
from .shared.browserbase_context_integration_def import BrowserbaseContextIntegrationDef
from .shared.browserbase_extension_integration_def import BrowserbaseExtensionIntegrationDef
from .shared.browserbase_get_session_integration_def import BrowserbaseGetSessionIntegrationDef
from .shared.browserbase_list_sessions_integration_def import BrowserbaseListSessionsIntegrationDef
from .shared.browserbase_create_session_integration_def import BrowserbaseCreateSessionIntegrationDef
from .shared.browserbase_complete_session_integration_def import BrowserbaseCompleteSessionIntegrationDef
from .shared.browserbase_get_session_live_urls_integration_def import BrowserbaseGetSessionLiveURLsIntegrationDef

__all__ = [
    "SessionRenderResponse",
    "Message",
    "MessageContentUnionMember2",
    "MessageContentUnionMember2ContentOutput",
    "MessageContentUnionMember2ContentModel7",
    "MessageContentUnionMember2ContentModel7ImageURL",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutput",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember0",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1Source",
    "MessageToolCall",
    "ToolChoice",
    "Tool",
    "ToolAPICall",
    "ToolAPICallParamsSchema",
    "ToolAPICallParamsSchemaProperties",
    "ToolIntegration",
]


class MessageContentUnionMember2ContentOutput(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MessageContentUnionMember2ContentModel7ImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MessageContentUnionMember2ContentModel7(BaseModel):
    image_url: MessageContentUnionMember2ContentModel7ImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1(BaseModel):
    source: MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutput(BaseModel):
    content: Union[
        List[MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember0],
        List[MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutputContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MessageContentUnionMember2: TypeAlias = Union[
    MessageContentUnionMember2ContentOutput,
    MessageContentUnionMember2ContentModel7,
    MessageContentUnionMember2AgentsAPIAutogenChatContentModelOutput,
]

MessageToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class Message(BaseModel):
    role: Literal["user", "assistant", "system", "tool"]

    content: Union[str, List[str], List[MessageContentUnionMember2], None] = None

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MessageToolCall]] = None


ToolChoice: TypeAlias = Union[Literal["auto", "none"], NamedToolChoice, None]


class ToolAPICallParamsSchemaProperties(BaseModel):
    type: str

    description: Optional[str] = None

    enum: Optional[List[str]] = None

    items: Optional[object] = None


class ToolAPICallParamsSchema(BaseModel):
    properties: Dict[str, ToolAPICallParamsSchemaProperties]

    additional_properties: Optional[bool] = FieldInfo(alias="additionalProperties", default=None)

    required: Optional[List[str]] = None

    type: Optional[str] = None


class ToolAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    include_response_content: Optional[bool] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    params_schema: Optional[ToolAPICallParamsSchema] = None
    """JSON Schema for API call parameters"""

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    secrets: Optional[Dict[str, SecretRef]] = None

    timeout: Optional[int] = None


ToolIntegration: TypeAlias = Union[
    DummyIntegrationDef,
    BraveIntegrationDef,
    EmailIntegrationDef,
    SpiderIntegrationDef,
    WikipediaIntegrationDef,
    WeatherIntegrationDef,
    MailgunIntegrationDef,
    BrowserbaseContextIntegrationDef,
    BrowserbaseExtensionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionIntegrationDef,
    BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef,
    RemoteBrowserIntegrationDef,
    LlamaParseIntegrationDef,
    FfmpegIntegrationDef,
    CloudinaryUploadIntegrationDef,
    CloudinaryEditIntegrationDef,
    ArxivIntegrationDef,
    UnstructuredIntegrationDef,
    AlgoliaIntegrationDef,
    None,
]


class Tool(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[ToolAPICall] = None
    """API call definition"""

    bash_20241022: Optional[Bash20241022Def] = None

    computer_20241022: Optional[Computer20241022Def] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[FunctionDef] = None
    """Function definition"""

    integration: Optional[ToolIntegration] = None
    """Brave integration definition"""

    system: Optional[SystemDef] = None
    """System definition"""

    text_editor_20241022: Optional[TextEditor20241022Def] = None


class SessionRenderResponse(BaseModel):
    messages: List[Message]

    docs: Optional[List[DocReference]] = None

    tool_choice: Optional[ToolChoice] = None

    tools: Optional[List[Tool]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["AlgoliaSetup"]


class AlgoliaSetup(BaseModel):
    algolia_api_key: str

    algolia_application_id: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel
from .get_step import GetStep
from .log_step import LogStep
from .set_step import SetStep
from .sleep_step import SleepStep
from .yield_step import YieldStep
from .return_step import ReturnStep
from .evaluate_step import EvaluateStep
from .tool_call_step import ToolCallStep
from .prompt_step_output import PromptStepOutput
from .error_workflow_step import ErrorWorkflowStep
from .wait_for_input_step import WaitForInputStep

__all__ = ["CaseThenOutput", "Then"]

Then: TypeAlias = Union[
    EvaluateStep,
    ToolCallStep,
    PromptStepOutput,
    GetStep,
    SetStep,
    LogStep,
    YieldStep,
    ReturnStep,
    SleepStep,
    ErrorWorkflowStep,
    WaitForInputStep,
]


class CaseThenOutput(BaseModel):
    case: Literal["_"]

    then: Then



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Union, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EvaluateStep"]


class EvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

__all__ = ["AlgoliaSearchArguments"]


class AlgoliaSearchArguments(TypedDict, total=False):
    index_name: Required[str]

    query: Required[str]

    attributes_to_retrieve: Optional[List[str]]

    hits_per_page: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .llama_parse_setup import LlamaParseSetup
from .llama_parse_fetch_arguments import LlamaParseFetchArguments

__all__ = ["LlamaParseIntegrationDef"]


class LlamaParseIntegrationDef(TypedDict, total=False):
    arguments: Optional[LlamaParseFetchArguments]
    """Arguments for LlamaParse integration"""

    method: Optional[str]

    provider: Literal["llama_parse"]

    setup: Optional[LlamaParseSetup]
    """Setup parameters for LlamaParse integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .brave_search_setup import BraveSearchSetup
from .brave_search_arguments import BraveSearchArguments

__all__ = ["BraveIntegrationDef"]


class BraveIntegrationDef(TypedDict, total=False):
    arguments: Optional[BraveSearchArguments]
    """Arguments for Brave Search"""

    method: Optional[str]

    provider: Literal["brave"]

    setup: Optional[BraveSearchSetup]
    """Integration definition for Brave Search"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ToolCallStep"]


class ToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .doc import Doc as Doc
from .file import File as File
from .task import Task as Task
from .user import User as User
from .agent import Agent as Agent
from .entry import Entry as Entry
from .secret import Secret as Secret
from .shared import (
    DocOwner as DocOwner,
    SecretRef as SecretRef,
    SystemDef as SystemDef,
    EmailSetup as EmailSetup,
    FunctionDef as FunctionDef,
    SpiderSetup as SpiderSetup,
    AlgoliaSetup as AlgoliaSetup,
    DocReference as DocReference,
    MailgunSetup as MailgunSetup,
    WeatherSetup as WeatherSetup,
    EmailArguments as EmailArguments,
    Bash20241022Def as Bash20241022Def,
    CloudinarySetup as CloudinarySetup,
    IfElseStepInput as IfElseStepInput,
    LlamaParseSetup as LlamaParseSetup,
    NamedToolChoice as NamedToolChoice,
    PromptStepInput as PromptStepInput,
    BraveSearchSetup as BraveSearchSetup,
    BrowserbaseSetup as BrowserbaseSetup,
    IfElseStepOutput as IfElseStepOutput,
    UnstructuredSetup as UnstructuredSetup,
    FunctionCallOption as FunctionCallOption,
    RemoteBrowserSetup as RemoteBrowserSetup,
    ArxivIntegrationDef as ArxivIntegrationDef,
    BraveIntegrationDef as BraveIntegrationDef,
    Computer20241022Def as Computer20241022Def,
    DummyIntegrationDef as DummyIntegrationDef,
    EmailIntegrationDef as EmailIntegrationDef,
    WeatherGetArguments as WeatherGetArguments,
    ArxivSearchArguments as ArxivSearchArguments,
    BraveSearchArguments as BraveSearchArguments,
    FfmpegIntegrationDef as FfmpegIntegrationDef,
    SpiderFetchArguments as SpiderFetchArguments,
    SpiderIntegrationDef as SpiderIntegrationDef,
    AlgoliaIntegrationDef as AlgoliaIntegrationDef,
    FfmpegSearchArguments as FfmpegSearchArguments,
    MailgunIntegrationDef as MailgunIntegrationDef,
    TextEditor20241022Def as TextEditor20241022Def,
    WeatherIntegrationDef as WeatherIntegrationDef,
    AlgoliaSearchArguments as AlgoliaSearchArguments,
    RemoteBrowserArguments as RemoteBrowserArguments,
    CloudinaryEditArguments as CloudinaryEditArguments,
    WikipediaIntegrationDef as WikipediaIntegrationDef,
    LlamaParseFetchArguments as LlamaParseFetchArguments,
    LlamaParseIntegrationDef as LlamaParseIntegrationDef,
    WikipediaSearchArguments as WikipediaSearchArguments,
    CloudinaryUploadArguments as CloudinaryUploadArguments,
    MailgunSendEmailArguments as MailgunSendEmailArguments,
    UnstructuredIntegrationDef as UnstructuredIntegrationDef,
    BrowserbaseContextArguments as BrowserbaseContextArguments,
    RemoteBrowserIntegrationDef as RemoteBrowserIntegrationDef,
    CloudinaryEditIntegrationDef as CloudinaryEditIntegrationDef,
    BrowserbaseExtensionArguments as BrowserbaseExtensionArguments,
    BrowserbaseGetSessionArguments as BrowserbaseGetSessionArguments,
    CloudinaryUploadIntegrationDef as CloudinaryUploadIntegrationDef,
    UnstructuredPartitionArguments as UnstructuredPartitionArguments,
    BrowserbaseContextIntegrationDef as BrowserbaseContextIntegrationDef,
    BrowserbaseListSessionsArguments as BrowserbaseListSessionsArguments,
    BrowserbaseCreateSessionArguments as BrowserbaseCreateSessionArguments,
    BrowserbaseExtensionIntegrationDef as BrowserbaseExtensionIntegrationDef,
    BrowserbaseCompleteSessionArguments as BrowserbaseCompleteSessionArguments,
    BrowserbaseGetSessionIntegrationDef as BrowserbaseGetSessionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef as BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef as BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsArguments as BrowserbaseGetSessionLiveURLsArguments,
    BrowserbaseCompleteSessionIntegrationDef as BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef as BrowserbaseGetSessionLiveURLsIntegrationDef,
)
from .history import History as History
from .session import Session as Session
from .snippet import Snippet as Snippet
from .get_step import GetStep as GetStep
from .log_step import LogStep as LogStep
from .set_step import SetStep as SetStep
from .execution import Execution as Execution
from .sleep_for import SleepFor as SleepFor
from .job_status import JobStatus as JobStatus
from .sleep_step import SleepStep as SleepStep
from .transition import Transition as Transition
from .yield_step import YieldStep as YieldStep
from .return_step import ReturnStep as ReturnStep
from .chat_response import ChatResponse as ChatResponse
from .evaluate_step import EvaluateStep as EvaluateStep
from .doc_get_params import DocGetParams as DocGetParams
from .get_step_param import GetStepParam as GetStepParam
from .log_step_param import LogStepParam as LogStepParam
from .set_step_param import SetStepParam as SetStepParam
from .token_log_prob import TokenLogProb as TokenLogProb
from .tool_call_step import ToolCallStep as ToolCallStep
from .sleep_for_param import SleepForParam as SleepForParam
from .case_then_output import CaseThenOutput as CaseThenOutput
from .doc_embed_params import DocEmbedParams as DocEmbedParams
from .sleep_step_param import SleepStepParam as SleepStepParam
from .task_list_params import TaskListParams as TaskListParams
from .user_list_params import UserListParams as UserListParams
from .yield_step_param import YieldStepParam as YieldStepParam
from .agent_list_params import AgentListParams as AgentListParams
from .foreach_do_output import ForeachDoOutput as ForeachDoOutput
from .hybrid_doc_search import HybridDocSearch as HybridDocSearch
from .log_prob_response import LogProbResponse as LogProbResponse
from .return_step_param import ReturnStepParam as ReturnStepParam
from .user_reset_params import UserResetParams as UserResetParams
from .vector_doc_search import VectorDocSearch as VectorDocSearch
from .agent_reset_params import AgentResetParams as AgentResetParams
from .file_create_params import FileCreateParams as FileCreateParams
from .file_list_response import FileListResponse as FileListResponse
from .prompt_step_output import PromptStepOutput as PromptStepOutput
from .secret_list_params import SecretListParams as SecretListParams
from .switch_step_output import SwitchStepOutput as SwitchStepOutput
from .task_create_params import TaskCreateParams as TaskCreateParams
from .user_create_params import UserCreateParams as UserCreateParams
from .user_update_params import UserUpdateParams as UserUpdateParams
from .agent_create_params import AgentCreateParams as AgentCreateParams
from .agent_update_params import AgentUpdateParams as AgentUpdateParams
from .base_token_log_prob import BaseTokenLogProb as BaseTokenLogProb
from .chosen_bash20241022 import ChosenBash20241022 as ChosenBash20241022
from .error_workflow_step import ErrorWorkflowStep as ErrorWorkflowStep
from .evaluate_step_param import EvaluateStepParam as EvaluateStepParam
from .foreach_step_output import ForeachStepOutput as ForeachStepOutput
from .project_list_params import ProjectListParams as ProjectListParams
from .session_chat_params import SessionChatParams as SessionChatParams
from .session_list_params import SessionListParams as SessionListParams
from .wait_for_input_info import WaitForInputInfo as WaitForInputInfo
from .wait_for_input_step import WaitForInputStep as WaitForInputStep
from .chosen_function_call import ChosenFunctionCall as ChosenFunctionCall
from .embed_query_response import EmbedQueryResponse as EmbedQueryResponse
from .file_delete_response import FileDeleteResponse as FileDeleteResponse
from .parallel_step_output import ParallelStepOutput as ParallelStepOutput
from .secret_create_params import SecretCreateParams as SecretCreateParams
from .secret_list_response import SecretListResponse as SecretListResponse
from .secret_update_params import SecretUpdateParams as SecretUpdateParams
from .session_reset_params import SessionResetParams as SessionResetParams
from .text_only_doc_search import TextOnlyDocSearch as TextOnlyDocSearch
from .tool_call_step_param import ToolCallStepParam as ToolCallStepParam
from .user_delete_response import UserDeleteResponse as UserDeleteResponse
from .agent_delete_response import AgentDeleteResponse as AgentDeleteResponse
from .execution_list_params import ExecutionListParams as ExecutionListParams
from .project_create_params import ProjectCreateParams as ProjectCreateParams
from .project_list_response import ProjectListResponse as ProjectListResponse
from .session_chat_response import SessionChatResponse as SessionChatResponse
from .session_create_params import SessionCreateParams as SessionCreateParams
from .session_render_params import SessionRenderParams as SessionRenderParams
from .session_update_params import SessionUpdateParams as SessionUpdateParams
from .secret_delete_response import SecretDeleteResponse as SecretDeleteResponse
from .chosen_computer20241022 import ChosenComputer20241022 as ChosenComputer20241022
from .execution_create_params import ExecutionCreateParams as ExecutionCreateParams
from .hybrid_doc_search_param import HybridDocSearchParam as HybridDocSearchParam
from .project_create_response import ProjectCreateResponse as ProjectCreateResponse
from .session_delete_response import SessionDeleteResponse as SessionDeleteResponse
from .session_render_response import SessionRenderResponse as SessionRenderResponse
from .vector_doc_search_param import VectorDocSearchParam as VectorDocSearchParam
from .chosen_bash20241022_param import ChosenBash20241022Param as ChosenBash20241022Param
from .error_workflow_step_param import ErrorWorkflowStepParam as ErrorWorkflowStepParam
from .wait_for_input_info_param import WaitForInputInfoParam as WaitForInputInfoParam
from .wait_for_input_step_param import WaitForInputStepParam as WaitForInputStepParam
from .agent_list_models_response import AgentListModelsResponse as AgentListModelsResponse
from .chosen_function_call_param import ChosenFunctionCallParam as ChosenFunctionCallParam
from .chosen_text_editor20241022 import ChosenTextEditor20241022 as ChosenTextEditor20241022
from .text_only_doc_search_param import TextOnlyDocSearchParam as TextOnlyDocSearchParam
from .task_create_or_update_params import TaskCreateOrUpdateParams as TaskCreateOrUpdateParams
from .user_create_or_update_params import UserCreateOrUpdateParams as UserCreateOrUpdateParams
from .agent_create_or_update_params import AgentCreateOrUpdateParams as AgentCreateOrUpdateParams
from .chosen_computer20241022_param import ChosenComputer20241022Param as ChosenComputer20241022Param
from .execution_change_status_params import ExecutionChangeStatusParams as ExecutionChangeStatusParams
from .session_create_or_update_params import SessionCreateOrUpdateParams as SessionCreateOrUpdateParams
from .chosen_text_editor20241022_param import ChosenTextEditor20241022Param as ChosenTextEditor20241022Param
from .schema_completion_response_format_param import (
    SchemaCompletionResponseFormatParam as SchemaCompletionResponseFormatParam,
)
from .simple_completion_response_format_param import (
    SimpleCompletionResponseFormatParam as SimpleCompletionResponseFormatParam,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .weather_setup import WeatherSetup
from .weather_get_arguments import WeatherGetArguments

__all__ = ["WeatherIntegrationDef"]


class WeatherIntegrationDef(BaseModel):
    arguments: Optional[WeatherGetArguments] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[WeatherSetup] = None
    """Integration definition for Weather"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["UnstructuredSetup"]


class UnstructuredSetup(BaseModel):
    unstructured_api_key: str

    retry_config: Optional[object] = None

    server: Optional[str] = None

    server_url: Optional[str] = None

    timeout_ms: Optional[int] = None

    url_params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .remote_browser_setup import RemoteBrowserSetup
from .remote_browser_arguments import RemoteBrowserArguments

__all__ = ["RemoteBrowserIntegrationDef"]


class RemoteBrowserIntegrationDef(BaseModel):
    setup: RemoteBrowserSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[RemoteBrowserArguments] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo
from .shared_params.secret_ref import SecretRef
from .shared_params.system_def import SystemDef
from .chosen_bash20241022_param import ChosenBash20241022Param
from .chosen_function_call_param import ChosenFunctionCallParam
from .shared_params.function_def import FunctionDef
from .chosen_computer20241022_param import ChosenComputer20241022Param
from .shared_params.bash20241022_def import Bash20241022Def
from .shared_params.named_tool_choice import NamedToolChoice
from .chosen_text_editor20241022_param import ChosenTextEditor20241022Param
from .shared_params.computer20241022_def import Computer20241022Def
from .shared_params.arxiv_integration_def import ArxivIntegrationDef
from .shared_params.brave_integration_def import BraveIntegrationDef
from .shared_params.dummy_integration_def import DummyIntegrationDef
from .shared_params.email_integration_def import EmailIntegrationDef
from .shared_params.ffmpeg_integration_def import FfmpegIntegrationDef
from .shared_params.spider_integration_def import SpiderIntegrationDef
from .shared_params.algolia_integration_def import AlgoliaIntegrationDef
from .shared_params.mailgun_integration_def import MailgunIntegrationDef
from .shared_params.text_editor20241022_def import TextEditor20241022Def
from .shared_params.weather_integration_def import WeatherIntegrationDef
from .schema_completion_response_format_param import SchemaCompletionResponseFormatParam
from .shared_params.wikipedia_integration_def import WikipediaIntegrationDef
from .simple_completion_response_format_param import SimpleCompletionResponseFormatParam
from .shared_params.llama_parse_integration_def import LlamaParseIntegrationDef
from .shared_params.unstructured_integration_def import UnstructuredIntegrationDef
from .shared_params.remote_browser_integration_def import RemoteBrowserIntegrationDef
from .shared_params.cloudinary_edit_integration_def import CloudinaryEditIntegrationDef
from .shared_params.cloudinary_upload_integration_def import CloudinaryUploadIntegrationDef
from .shared_params.browserbase_context_integration_def import BrowserbaseContextIntegrationDef
from .shared_params.browserbase_extension_integration_def import BrowserbaseExtensionIntegrationDef
from .shared_params.browserbase_get_session_integration_def import BrowserbaseGetSessionIntegrationDef
from .shared_params.browserbase_list_sessions_integration_def import BrowserbaseListSessionsIntegrationDef
from .shared_params.browserbase_create_session_integration_def import BrowserbaseCreateSessionIntegrationDef
from .shared_params.browserbase_complete_session_integration_def import BrowserbaseCompleteSessionIntegrationDef
from .shared_params.browserbase_get_session_live_urls_integration_def import BrowserbaseGetSessionLiveURLsIntegrationDef

__all__ = [
    "SessionRenderParams",
    "Message",
    "MessageContentUnionMember2",
    "MessageContentUnionMember2AgentsAPIAutogenChatContent",
    "MessageContentUnionMember2ContentModel7",
    "MessageContentUnionMember2ContentModel7ImageURL",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelInput",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember0",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1",
    "MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1Source",
    "MessageToolCall",
    "ResponseFormat",
    "ToolChoice",
    "Tool",
    "ToolAPICall",
    "ToolAPICallParamsSchema",
    "ToolAPICallParamsSchemaProperties",
    "ToolIntegration",
]


class SessionRenderParams(TypedDict, total=False):
    messages: Required[Iterable[Message]]

    agent: Optional[str]

    auto_run_tools: bool

    frequency_penalty: Optional[float]

    length_penalty: Optional[float]

    logit_bias: Optional[Dict[str, float]]

    max_tokens: Optional[int]

    metadata: Optional[object]

    min_p: Optional[float]

    model: Optional[str]

    presence_penalty: Optional[float]

    recall: bool

    recall_tools: bool

    repetition_penalty: Optional[float]

    response_format: Optional[ResponseFormat]

    save: bool

    seed: Optional[int]

    stop: List[str]

    stream: bool

    temperature: Optional[float]

    tool_choice: Optional[ToolChoice]

    tools: Optional[Iterable[Tool]]

    top_p: Optional[float]


class MessageContentUnionMember2AgentsAPIAutogenChatContent(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MessageContentUnionMember2ContentModel7ImageURL(TypedDict, total=False):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class MessageContentUnionMember2ContentModel7(TypedDict, total=False):
    image_url: Required[MessageContentUnionMember2ContentModel7ImageURL]
    """The image URL"""

    type: Literal["image_url"]


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember0(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1Source(TypedDict, total=False):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1(TypedDict, total=False):
    source: Required[MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1Source]

    type: Literal["image"]


class MessageContentUnionMember2AgentsAPIAutogenChatContentModelInput(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember0],
            Iterable[MessageContentUnionMember2AgentsAPIAutogenChatContentModelInputContentUnionMember1],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


MessageContentUnionMember2: TypeAlias = Union[
    MessageContentUnionMember2AgentsAPIAutogenChatContent,
    MessageContentUnionMember2ContentModel7,
    MessageContentUnionMember2AgentsAPIAutogenChatContentModelInput,
]

MessageToolCall: TypeAlias = Union[
    ChosenFunctionCallParam, ChosenComputer20241022Param, ChosenTextEditor20241022Param, ChosenBash20241022Param
]


class Message(TypedDict, total=False):
    role: Required[Literal["user", "assistant", "system", "tool"]]

    content: Union[str, List[str], Iterable[MessageContentUnionMember2], None]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[MessageToolCall]]


ResponseFormat: TypeAlias = Union[SimpleCompletionResponseFormatParam, SchemaCompletionResponseFormatParam]

ToolChoice: TypeAlias = Union[Literal["auto", "none"], NamedToolChoice]


class ToolAPICallParamsSchemaProperties(TypedDict, total=False):
    type: Required[str]

    description: Optional[str]

    enum: Optional[List[str]]

    items: object


class ToolAPICallParamsSchema(TypedDict, total=False):
    properties: Required[Dict[str, ToolAPICallParamsSchemaProperties]]

    additional_properties: Annotated[Optional[bool], PropertyInfo(alias="additionalProperties")]

    required: List[str]

    type: str


class ToolAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    params_schema: Optional[ToolAPICallParamsSchema]
    """JSON Schema for API call parameters"""

    schema: Optional[object]

    secrets: Optional[Dict[str, SecretRef]]

    timeout: Optional[int]


ToolIntegration: TypeAlias = Union[
    DummyIntegrationDef,
    BraveIntegrationDef,
    EmailIntegrationDef,
    SpiderIntegrationDef,
    WikipediaIntegrationDef,
    WeatherIntegrationDef,
    MailgunIntegrationDef,
    BrowserbaseContextIntegrationDef,
    BrowserbaseExtensionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionIntegrationDef,
    BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef,
    RemoteBrowserIntegrationDef,
    LlamaParseIntegrationDef,
    FfmpegIntegrationDef,
    CloudinaryUploadIntegrationDef,
    CloudinaryEditIntegrationDef,
    ArxivIntegrationDef,
    UnstructuredIntegrationDef,
    AlgoliaIntegrationDef,
]


class Tool(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[ToolAPICall]
    """API call definition"""

    bash_20241022: Optional[Bash20241022Def]

    computer_20241022: Optional[Computer20241022Def]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[FunctionDef]
    """Function definition"""

    integration: Optional[ToolIntegration]
    """Brave integration definition"""

    system: Optional[SystemDef]
    """System definition"""

    text_editor_20241022: Optional[TextEditor20241022Def]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable
from typing_extensions import Required, TypedDict

__all__ = ["WaitForInputInfoParam"]


class WaitForInputInfoParam(TypedDict, total=False):
    info: Required[Dict[str, Union[List[str], Dict[str, str], Iterable[Dict[str, str]], str]]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .base_token_log_prob import BaseTokenLogProb

__all__ = ["TokenLogProb"]


class TokenLogProb(BaseModel):
    token: str

    logprob: float

    top_logprobs: List[BaseTokenLogProb]

    bytes: Optional[List[int]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union

from .._models import BaseModel

__all__ = ["WaitForInputInfo"]


class WaitForInputInfo(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .mailgun_setup import MailgunSetup
from .mailgun_send_email_arguments import MailgunSendEmailArguments

__all__ = ["MailgunIntegrationDef"]


class MailgunIntegrationDef(BaseModel):
    arguments: Optional[MailgunSendEmailArguments] = None
    """Arguments for mailgun.send_email method"""

    method: Optional[Literal["send_email"]] = None

    provider: Optional[Literal["mailgun"]] = None

    setup: Optional[MailgunSetup] = None
    """Setup parameters for Mailgun integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .foreach_do_output import ForeachDoOutput

__all__ = ["ForeachStepOutput"]


class ForeachStepOutput(BaseModel):
    foreach: ForeachDoOutput

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["AlgoliaSetup"]


class AlgoliaSetup(TypedDict, total=False):
    algolia_api_key: Required[str]

    algolia_application_id: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .browserbase_setup import BrowserbaseSetup
from .browserbase_list_sessions_arguments import BrowserbaseListSessionsArguments

__all__ = ["BrowserbaseListSessionsIntegrationDef"]


class BrowserbaseListSessionsIntegrationDef(TypedDict, total=False):
    arguments: Optional[BrowserbaseListSessionsArguments]

    method: Literal["list_sessions"]

    provider: Literal["browserbase"]

    setup: Optional[BrowserbaseSetup]
    """The setup parameters for the browserbase integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import TYPE_CHECKING, List, Union, Optional
from typing_extensions import Literal, TypeAlias, TypeAliasType

from pydantic import Field as FieldInfo

from ..._compat import PYDANTIC_V2
from ..._models import BaseModel
from ..get_step import GetStep
from ..log_step import LogStep
from ..set_step import SetStep
from ..sleep_step import SleepStep
from ..yield_step import YieldStep
from ..return_step import ReturnStep
from ..evaluate_step import EvaluateStep
from ..tool_call_step import ToolCallStep
from .prompt_step_input import PromptStepInput
from ..error_workflow_step import ErrorWorkflowStep
from ..wait_for_input_step import WaitForInputStep

__all__ = [
    "IfElseStepInput",
    "Then",
    "ThenSwitchStepInput",
    "ThenSwitchStepInputSwitch",
    "ThenSwitchStepInputSwitchThen",
    "ThenForeachStepInput",
    "ThenForeachStepInputForeach",
    "ThenForeachStepInputForeachDo",
    "ThenParallelStepInput",
    "ThenParallelStepInputParallel",
    "ThenThenInput",
    "ThenThenInputMap",
    "Else",
    "ElseSwitchStepInput",
    "ElseSwitchStepInputSwitch",
    "ElseSwitchStepInputSwitchThen",
    "ElseForeachStepInput",
    "ElseForeachStepInputForeach",
    "ElseForeachStepInputForeachDo",
    "ElseParallelStepInput",
    "ElseParallelStepInputParallel",
    "ElseElseInput",
    "ElseElseInputMap",
]

ThenSwitchStepInputSwitchThen: TypeAlias = Union[
    EvaluateStep,
    ToolCallStep,
    PromptStepInput,
    GetStep,
    SetStep,
    LogStep,
    YieldStep,
    ReturnStep,
    SleepStep,
    ErrorWorkflowStep,
    WaitForInputStep,
]


class ThenSwitchStepInputSwitch(BaseModel):
    case: Literal["_"]

    then: ThenSwitchStepInputSwitchThen


class ThenSwitchStepInput(BaseModel):
    switch: List[ThenSwitchStepInputSwitch]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ThenForeachStepInputForeachDo: TypeAlias = Union[
    WaitForInputStep, EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep
]


class ThenForeachStepInputForeach(BaseModel):
    do: ThenForeachStepInputForeachDo

    in_: str = FieldInfo(alias="in")


class ThenForeachStepInput(BaseModel):
    foreach: ThenForeachStepInputForeach

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ThenParallelStepInputParallel: TypeAlias = Union[
    EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep
]


class ThenParallelStepInput(BaseModel):
    parallel: List[ThenParallelStepInputParallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ThenThenInputMap: TypeAlias = Union[EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep]


class ThenThenInput(BaseModel):
    map: ThenThenInputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


if TYPE_CHECKING or PYDANTIC_V2:
    Then = TypeAliasType(
        "Then",
        Union[
            WaitForInputStep,
            EvaluateStep,
            ToolCallStep,
            PromptStepInput,
            GetStep,
            SetStep,
            LogStep,
            YieldStep,
            ReturnStep,
            SleepStep,
            ErrorWorkflowStep,
            "IfElseStepInput",
            ThenSwitchStepInput,
            ThenForeachStepInput,
            ThenParallelStepInput,
            ThenThenInput,
        ],
    )
else:
    Then: TypeAlias = Union[
        WaitForInputStep,
        EvaluateStep,
        ToolCallStep,
        PromptStepInput,
        GetStep,
        SetStep,
        LogStep,
        YieldStep,
        ReturnStep,
        SleepStep,
        ErrorWorkflowStep,
        "IfElseStepInput",
        ThenSwitchStepInput,
        ThenForeachStepInput,
        ThenParallelStepInput,
        ThenThenInput,
    ]

ElseSwitchStepInputSwitchThen: TypeAlias = Union[
    EvaluateStep,
    ToolCallStep,
    PromptStepInput,
    GetStep,
    SetStep,
    LogStep,
    YieldStep,
    ReturnStep,
    SleepStep,
    ErrorWorkflowStep,
    WaitForInputStep,
]


class ElseSwitchStepInputSwitch(BaseModel):
    case: Literal["_"]

    then: ElseSwitchStepInputSwitchThen


class ElseSwitchStepInput(BaseModel):
    switch: List[ElseSwitchStepInputSwitch]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ElseForeachStepInputForeachDo: TypeAlias = Union[
    WaitForInputStep, EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep
]


class ElseForeachStepInputForeach(BaseModel):
    do: ElseForeachStepInputForeachDo

    in_: str = FieldInfo(alias="in")


class ElseForeachStepInput(BaseModel):
    foreach: ElseForeachStepInputForeach

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ElseParallelStepInputParallel: TypeAlias = Union[
    EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep
]


class ElseParallelStepInput(BaseModel):
    parallel: List[ElseParallelStepInputParallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


ElseElseInputMap: TypeAlias = Union[EvaluateStep, ToolCallStep, PromptStepInput, GetStep, SetStep, LogStep, YieldStep]


class ElseElseInput(BaseModel):
    map: ElseElseInputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


if TYPE_CHECKING or PYDANTIC_V2:
    Else = TypeAliasType(
        "Else",
        Union[
            WaitForInputStep,
            EvaluateStep,
            ToolCallStep,
            PromptStepInput,
            GetStep,
            SetStep,
            LogStep,
            YieldStep,
            ReturnStep,
            SleepStep,
            ErrorWorkflowStep,
            "IfElseStepInput",
            ElseSwitchStepInput,
            ElseForeachStepInput,
            ElseParallelStepInput,
            ElseElseInput,
            None,
        ],
    )
else:
    Else: TypeAlias = Union[
        WaitForInputStep,
        EvaluateStep,
        ToolCallStep,
        PromptStepInput,
        GetStep,
        SetStep,
        LogStep,
        YieldStep,
        ReturnStep,
        SleepStep,
        ErrorWorkflowStep,
        "IfElseStepInput",
        ElseSwitchStepInput,
        ElseForeachStepInput,
        ElseParallelStepInput,
        ElseElseInput,
        None,
    ]


class IfElseStepInput(BaseModel):
    if_: str = FieldInfo(alias="if")

    then: Then
    """The steps to run if the condition is true"""

    else_: Optional[Else] = FieldInfo(alias="else", default=None)
    """The steps to run if the condition is false"""

    kind: Optional[Literal["if_else"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


if PYDANTIC_V2:
    IfElseStepInput.model_rebuild()
    ThenSwitchStepInput.model_rebuild()
    ThenSwitchStepInputSwitch.model_rebuild()
    ThenForeachStepInput.model_rebuild()
    ThenForeachStepInputForeach.model_rebuild()
    ThenParallelStepInput.model_rebuild()
    ThenThenInput.model_rebuild()
    ElseSwitchStepInput.model_rebuild()
    ElseSwitchStepInputSwitch.model_rebuild()
    ElseForeachStepInput.model_rebuild()
    ElseForeachStepInputForeach.model_rebuild()
    ElseParallelStepInput.model_rebuild()
    ElseElseInput.model_rebuild()
else:
    IfElseStepInput.update_forward_refs()  # type: ignore
    ThenSwitchStepInput.update_forward_refs()  # type: ignore
    ThenSwitchStepInputSwitch.update_forward_refs()  # type: ignore
    ThenForeachStepInput.update_forward_refs()  # type: ignore
    ThenForeachStepInputForeach.update_forward_refs()  # type: ignore
    ThenParallelStepInput.update_forward_refs()  # type: ignore
    ThenThenInput.update_forward_refs()  # type: ignore
    ElseSwitchStepInput.update_forward_refs()  # type: ignore
    ElseSwitchStepInputSwitch.update_forward_refs()  # type: ignore
    ElseForeachStepInput.update_forward_refs()  # type: ignore
    ElseForeachStepInputForeach.update_forward_refs()  # type: ignore
    ElseParallelStepInput.update_forward_refs()  # type: ignore
    ElseElseInput.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .ffmpeg_search_arguments import FfmpegSearchArguments

__all__ = ["FfmpegIntegrationDef"]


class FfmpegIntegrationDef(TypedDict, total=False):
    arguments: Optional[FfmpegSearchArguments]
    """Arguments for Ffmpeg CMD"""

    method: Optional[str]

    provider: Literal["ffmpeg"]

    setup: object



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["BraveSearchSetup"]


class BraveSearchSetup(BaseModel):
    brave_api_key: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["SpiderFetchArguments"]


class SpiderFetchArguments(TypedDict, total=False):
    url: Required[str]

    content_type: Literal["application/json", "text/csv", "application/xml", "application/jsonl"]

    params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ToolCallStepParam"]


class ToolCallStepParam(TypedDict, total=False):
    tool: Required[str]

    arguments: Union[Literal["_"], object]

    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .wikipedia_search_arguments import WikipediaSearchArguments

__all__ = ["WikipediaIntegrationDef"]


class WikipediaIntegrationDef(BaseModel):
    arguments: Optional[WikipediaSearchArguments] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from .chosen_bash20241022_param import ChosenBash20241022Param
from .chosen_computer20241022_param import ChosenComputer20241022Param
from .chosen_text_editor20241022_param import ChosenTextEditor20241022Param
from .shared_params.function_call_option import FunctionCallOption

__all__ = ["ChosenFunctionCallParam"]


class ChosenFunctionCallParam(TypedDict, total=False):
    function: Required[FunctionCallOption]

    api_call: object

    bash_20241022: Optional[ChosenBash20241022Param]

    computer_20241022: Optional[ChosenComputer20241022Param]

    integration: object

    system: object

    text_editor_20241022: Optional[ChosenTextEditor20241022Param]

    type: Literal["function"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["FunctionDef"]


class FunctionDef(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Union, Optional
from typing_extensions import Required, TypedDict

__all__ = ["SetStepParam"]


class SetStepParam(TypedDict, total=False):
    set: Required[Dict[str, Union[str, object]]]

    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["MailgunSendEmailArguments"]


class MailgunSendEmailArguments(BaseModel):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str

    bcc: Optional[str] = None

    cc: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["SpiderFetchArguments"]


class SpiderFetchArguments(BaseModel):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel
from .chosen_bash20241022 import ChosenBash20241022
from .chosen_computer20241022 import ChosenComputer20241022
from .chosen_text_editor20241022 import ChosenTextEditor20241022
from .shared.function_call_option import FunctionCallOption

__all__ = ["ChosenFunctionCall"]


class ChosenFunctionCall(BaseModel):
    function: FunctionCallOption

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[ChosenBash20241022] = None

    computer_20241022: Optional[ChosenComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[ChosenTextEditor20241022] = None

    type: Optional[Literal["function"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["YieldStep"]


class YieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .case_then_output import CaseThenOutput

__all__ = ["SwitchStepOutput"]


class SwitchStepOutput(BaseModel):
    switch: List[CaseThenOutput]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SchemaCompletionResponseFormatParam"]


class SchemaCompletionResponseFormatParam(TypedDict, total=False):
    json_schema: Required[object]

    type: Literal["json_schema"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .function_call_option import FunctionCallOption

__all__ = ["NamedToolChoice"]


class NamedToolChoice(BaseModel):
    function: Optional[FunctionCallOption] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, TypedDict

__all__ = ["CloudinaryEditArguments"]


class CloudinaryEditArguments(TypedDict, total=False):
    public_id: Required[str]

    transformation: Required[Iterable[object]]

    return_base64: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["DocOwner"]


class DocOwner(BaseModel):
    id: str

    role: Literal["user", "agent"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["BrowserbaseCompleteSessionArguments"]


class BrowserbaseCompleteSessionArguments(TypedDict, total=False):
    id: Required[str]

    status: Literal["REQUEST_RELEASE"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .algolia_setup import AlgoliaSetup
from .algolia_search_arguments import AlgoliaSearchArguments

__all__ = ["AlgoliaIntegrationDef"]


class AlgoliaIntegrationDef(BaseModel):
    arguments: Optional[AlgoliaSearchArguments] = None
    """Arguments for Algolia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["algolia"]] = None

    setup: Optional[AlgoliaSetup] = None
    """Integration definition for Algolia"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .browserbase_setup import BrowserbaseSetup
from .browserbase_extension_arguments import BrowserbaseExtensionArguments

__all__ = ["BrowserbaseExtensionIntegrationDef"]


class BrowserbaseExtensionIntegrationDef(TypedDict, total=False):
    arguments: Optional[BrowserbaseExtensionArguments]

    method: Optional[Literal["install_extension_from_github"]]

    provider: Literal["browserbase"]

    setup: Optional[BrowserbaseSetup]
    """The setup parameters for the browserbase integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .email_setup import EmailSetup
from .email_arguments import EmailArguments

__all__ = ["EmailIntegrationDef"]


class EmailIntegrationDef(BaseModel):
    arguments: Optional[EmailArguments] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[EmailSetup] = None
    """Setup parameters for Email integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["BrowserbaseExtensionArguments"]


class BrowserbaseExtensionArguments(TypedDict, total=False):
    repository_name: Required[Annotated[str, PropertyInfo(alias="repositoryName")]]

    ref: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["BrowserbaseExtensionArguments"]


class BrowserbaseExtensionArguments(BaseModel):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["Bash20241022Def"]


class Bash20241022Def(TypedDict, total=False):
    name: str

    type: Literal["bash_20241022"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .cloudinary_setup import CloudinarySetup
from .cloudinary_upload_arguments import CloudinaryUploadArguments

__all__ = ["CloudinaryUploadIntegrationDef"]


class CloudinaryUploadIntegrationDef(TypedDict, total=False):
    arguments: Optional[CloudinaryUploadArguments]
    """Arguments for Cloudinary media upload"""

    method: Literal["media_upload"]

    provider: Literal["cloudinary"]

    setup: Optional[CloudinarySetup]
    """Setup parameters for Cloudinary integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["WeatherSetup"]


class WeatherSetup(BaseModel):
    openweathermap_api_key: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["CloudinaryEditArguments"]


class CloudinaryEditArguments(BaseModel):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .get_step import GetStep
from .log_step import LogStep
from .set_step import SetStep
from .yield_step import YieldStep
from .evaluate_step import EvaluateStep
from .tool_call_step import ToolCallStep
from .prompt_step_output import PromptStepOutput
from .wait_for_input_step import WaitForInputStep

__all__ = ["ForeachDoOutput", "Do"]

Do: TypeAlias = Union[
    WaitForInputStep, EvaluateStep, ToolCallStep, PromptStepOutput, GetStep, SetStep, LogStep, YieldStep
]


class ForeachDoOutput(BaseModel):
    do: Do

    in_: str = FieldInfo(alias="in")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["Computer20241022Def"]


class Computer20241022Def(TypedDict, total=False):
    display_height_px: int

    display_number: int

    display_width_px: int

    name: str

    type: Literal["computer_20241022"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .arxiv_search_arguments import ArxivSearchArguments

__all__ = ["ArxivIntegrationDef"]


class ArxivIntegrationDef(BaseModel):
    arguments: Optional[ArxivSearchArguments] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["BrowserbaseCreateSessionArguments"]


class BrowserbaseCreateSessionArguments(BaseModel):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from .wait_for_input_info_param import WaitForInputInfoParam

__all__ = ["WaitForInputStepParam"]


class WaitForInputStepParam(TypedDict, total=False):
    wait_for_input: Required[WaitForInputInfoParam]

    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ..._utils import PropertyInfo
from .secret_ref import SecretRef
from .system_def import SystemDef
from .function_def import FunctionDef
from .bash20241022_def import Bash20241022Def
from .named_tool_choice import NamedToolChoice
from .computer20241022_def import Computer20241022Def
from .arxiv_integration_def import ArxivIntegrationDef
from .brave_integration_def import BraveIntegrationDef
from .dummy_integration_def import DummyIntegrationDef
from .email_integration_def import EmailIntegrationDef
from .ffmpeg_integration_def import FfmpegIntegrationDef
from .spider_integration_def import SpiderIntegrationDef
from .algolia_integration_def import AlgoliaIntegrationDef
from .mailgun_integration_def import MailgunIntegrationDef
from .text_editor20241022_def import TextEditor20241022Def
from .weather_integration_def import WeatherIntegrationDef
from .wikipedia_integration_def import WikipediaIntegrationDef
from ..chosen_bash20241022_param import ChosenBash20241022Param
from ..chosen_function_call_param import ChosenFunctionCallParam
from .llama_parse_integration_def import LlamaParseIntegrationDef
from .unstructured_integration_def import UnstructuredIntegrationDef
from ..chosen_computer20241022_param import ChosenComputer20241022Param
from .remote_browser_integration_def import RemoteBrowserIntegrationDef
from .cloudinary_edit_integration_def import CloudinaryEditIntegrationDef
from ..chosen_text_editor20241022_param import ChosenTextEditor20241022Param
from .cloudinary_upload_integration_def import CloudinaryUploadIntegrationDef
from .browserbase_context_integration_def import BrowserbaseContextIntegrationDef
from .browserbase_extension_integration_def import BrowserbaseExtensionIntegrationDef
from .browserbase_get_session_integration_def import BrowserbaseGetSessionIntegrationDef
from .browserbase_list_sessions_integration_def import BrowserbaseListSessionsIntegrationDef
from .browserbase_create_session_integration_def import BrowserbaseCreateSessionIntegrationDef
from .browserbase_complete_session_integration_def import BrowserbaseCompleteSessionIntegrationDef
from .browserbase_get_session_live_urls_integration_def import BrowserbaseGetSessionLiveURLsIntegrationDef

__all__ = [
    "PromptStepInput",
    "PromptUnionMember0",
    "PromptUnionMember0ContentUnionMember1",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "PromptUnionMember0ContentUnionMember1ContentModel1Input",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "PromptUnionMember0ToolCall",
    "ToolChoice",
    "ToolsUnionMember1",
    "ToolsUnionMember1ToolRef",
    "ToolsUnionMember1ToolRefRef",
    "ToolsUnionMember1ToolRefRefToolRefByID",
    "ToolsUnionMember1ToolRefRefToolRefByName",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
]


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(TypedDict, total=False):
    url: Required[str]

    detail: Literal["low", "high", "auto"]


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(TypedDict, total=False):
    image_url: Required[PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL]
    """The image URL"""

    type: Literal["image_url"]


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(TypedDict, total=False):
    text: Required[str]

    type: Literal["text"]


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(TypedDict, total=False):
    data: Required[str]

    media_type: Required[str]

    type: Literal["base64"]


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(TypedDict, total=False):
    source: Required[PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source]

    type: Literal["image"]


class PromptUnionMember0ContentUnionMember1ContentModel1Input(TypedDict, total=False):
    content: Required[
        Union[
            Iterable[PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0],
            Iterable[PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1],
        ]
    ]

    tool_use_id: Required[str]

    type: Literal["tool_result"]


PromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent,
    PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    PromptUnionMember0ContentUnionMember1ContentModel1Input,
]

PromptUnionMember0ToolCall: TypeAlias = Union[
    ChosenFunctionCallParam, ChosenComputer20241022Param, ChosenTextEditor20241022Param, ChosenBash20241022Param
]


class PromptUnionMember0(TypedDict, total=False):
    content: Required[Union[List[str], Iterable[PromptUnionMember0ContentUnionMember1], str, None]]

    role: Required[Literal["user", "assistant", "system", "tool"]]

    name: Optional[str]

    tool_call_id: Optional[str]

    tool_calls: Optional[Iterable[PromptUnionMember0ToolCall]]


ToolChoice: TypeAlias = Union[Literal["auto", "none"], NamedToolChoice]


class ToolsUnionMember1ToolRefRefToolRefByID(TypedDict, total=False):
    id: Optional[str]


class ToolsUnionMember1ToolRefRefToolRefByName(TypedDict, total=False):
    name: Optional[str]


ToolsUnionMember1ToolRefRef: TypeAlias = Union[
    ToolsUnionMember1ToolRefRefToolRefByID, ToolsUnionMember1ToolRefRefToolRefByName
]


class ToolsUnionMember1ToolRef(TypedDict, total=False):
    ref: Required[ToolsUnionMember1ToolRefRef]
    """Reference to a tool by id"""


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties(TypedDict, total=False):
    type: Required[str]

    description: Optional[str]

    enum: Optional[List[str]]

    items: object


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema(TypedDict, total=False):
    properties: Required[
        Dict[str, ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties]
    ]

    additional_properties: Annotated[Optional[bool], PropertyInfo(alias="additionalProperties")]

    required: List[str]

    type: str


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    params_schema: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema]
    """JSON Schema for API call parameters"""

    schema: Optional[object]

    secrets: Optional[Dict[str, SecretRef]]

    timeout: Optional[int]


ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    DummyIntegrationDef,
    BraveIntegrationDef,
    EmailIntegrationDef,
    SpiderIntegrationDef,
    WikipediaIntegrationDef,
    WeatherIntegrationDef,
    MailgunIntegrationDef,
    BrowserbaseContextIntegrationDef,
    BrowserbaseExtensionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionIntegrationDef,
    BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef,
    RemoteBrowserIntegrationDef,
    LlamaParseIntegrationDef,
    FfmpegIntegrationDef,
    CloudinaryUploadIntegrationDef,
    CloudinaryEditIntegrationDef,
    ArxivIntegrationDef,
    UnstructuredIntegrationDef,
    AlgoliaIntegrationDef,
]


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(TypedDict, total=False):
    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall]
    """API call definition"""

    bash_20241022: Optional[Bash20241022Def]

    computer_20241022: Optional[Computer20241022Def]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[FunctionDef]
    """Function definition"""

    integration: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration]
    """Brave integration definition"""

    system: Optional[SystemDef]
    """System definition"""

    text_editor_20241022: Optional[TextEditor20241022Def]


ToolsUnionMember1: TypeAlias = Union[
    ToolsUnionMember1ToolRef, ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput
]


class PromptStepInput(TypedDict, total=False):
    prompt: Required[Union[Iterable[PromptUnionMember0], str]]

    auto_run_tools: bool

    disable_cache: bool

    label: Optional[str]

    settings: Optional[object]

    tool_choice: Optional[ToolChoice]

    tools: Union[Literal["all"], Iterable[ToolsUnionMember1]]

    unwrap: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

__all__ = ["VectorDocSearchParam"]


class VectorDocSearchParam(TypedDict, total=False):
    confidence: float

    include_embeddings: bool

    lang: str

    limit: int

    max_query_length: int

    metadata_filter: object

    mmr_strength: float

    mode: Literal["vector"]

    num_search_messages: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["FunctionDef"]


class FunctionDef(TypedDict, total=False):
    description: object

    name: object

    parameters: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["RemoteBrowserArguments"]


class RemoteBrowserArguments(TypedDict, total=False):
    action: Required[
        Literal[
            "key",
            "type",
            "mouse_move",
            "left_click",
            "left_click_drag",
            "right_click",
            "middle_click",
            "double_click",
            "screenshot",
            "cursor_position",
            "navigate",
            "refresh",
        ]
    ]

    connect_url: Optional[str]

    coordinate: Optional[Iterable[object]]

    text: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

__all__ = ["DummyIntegrationDef"]


class DummyIntegrationDef(TypedDict, total=False):
    arguments: object

    method: Optional[str]

    provider: Literal["dummy"]

    setup: object



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .llama_parse_setup import LlamaParseSetup
from .llama_parse_fetch_arguments import LlamaParseFetchArguments

__all__ = ["LlamaParseIntegrationDef"]


class LlamaParseIntegrationDef(BaseModel):
    arguments: Optional[LlamaParseFetchArguments] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[LlamaParseSetup] = None
    """Setup parameters for LlamaParse integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel
from .unstructured_setup import UnstructuredSetup
from .unstructured_partition_arguments import UnstructuredPartitionArguments

__all__ = ["UnstructuredIntegrationDef"]


class UnstructuredIntegrationDef(BaseModel):
    arguments: Optional[UnstructuredPartitionArguments] = None
    """Arguments for Unstructured partition integration"""

    method: Optional[str] = None

    provider: Optional[Literal["unstructured"]] = None

    setup: Optional[UnstructuredSetup] = None
    """Setup parameters for Unstructured integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

from .email_setup import EmailSetup
from .email_arguments import EmailArguments

__all__ = ["EmailIntegrationDef"]


class EmailIntegrationDef(TypedDict, total=False):
    arguments: Optional[EmailArguments]
    """Arguments for Email sending"""

    method: Optional[str]

    provider: Literal["email"]

    setup: Optional[EmailSetup]
    """Setup parameters for Email integration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["WikipediaSearchArguments"]


class WikipediaSearchArguments(BaseModel):
    query: str

    load_max_docs: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["ArxivSearchArguments"]


class ArxivSearchArguments(BaseModel):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

from .sleep_for_param import SleepForParam

__all__ = ["SleepStepParam"]


class SleepStepParam(TypedDict, total=False):
    sleep: Required[SleepForParam]

    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, TypedDict

__all__ = ["BrowserbaseListSessionsArguments"]


class BrowserbaseListSessionsArguments(TypedDict, total=False):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from ..._utils import PropertyInfo
from ..shared_params.secret_ref import SecretRef
from ..shared_params.system_def import SystemDef
from ..shared_params.function_def import FunctionDef
from ..shared_params.bash20241022_def import Bash20241022Def
from ..shared_params.computer20241022_def import Computer20241022Def
from ..shared_params.arxiv_integration_def import ArxivIntegrationDef
from ..shared_params.brave_integration_def import BraveIntegrationDef
from ..shared_params.dummy_integration_def import DummyIntegrationDef
from ..shared_params.email_integration_def import EmailIntegrationDef
from ..shared_params.ffmpeg_integration_def import FfmpegIntegrationDef
from ..shared_params.spider_integration_def import SpiderIntegrationDef
from ..shared_params.algolia_integration_def import AlgoliaIntegrationDef
from ..shared_params.mailgun_integration_def import MailgunIntegrationDef
from ..shared_params.text_editor20241022_def import TextEditor20241022Def
from ..shared_params.weather_integration_def import WeatherIntegrationDef
from ..shared_params.wikipedia_integration_def import WikipediaIntegrationDef
from ..shared_params.llama_parse_integration_def import LlamaParseIntegrationDef
from ..shared_params.unstructured_integration_def import UnstructuredIntegrationDef
from ..shared_params.remote_browser_integration_def import RemoteBrowserIntegrationDef
from ..shared_params.cloudinary_edit_integration_def import CloudinaryEditIntegrationDef
from ..shared_params.cloudinary_upload_integration_def import CloudinaryUploadIntegrationDef
from ..shared_params.browserbase_context_integration_def import BrowserbaseContextIntegrationDef
from ..shared_params.browserbase_extension_integration_def import BrowserbaseExtensionIntegrationDef
from ..shared_params.browserbase_get_session_integration_def import BrowserbaseGetSessionIntegrationDef
from ..shared_params.browserbase_list_sessions_integration_def import BrowserbaseListSessionsIntegrationDef
from ..shared_params.browserbase_create_session_integration_def import BrowserbaseCreateSessionIntegrationDef
from ..shared_params.browserbase_complete_session_integration_def import BrowserbaseCompleteSessionIntegrationDef
from ..shared_params.browserbase_get_session_live_urls_integration_def import (
    BrowserbaseGetSessionLiveURLsIntegrationDef,
)

__all__ = ["ToolResetParams", "APICall", "APICallParamsSchema", "APICallParamsSchemaProperties", "Integration"]


class ToolResetParams(TypedDict, total=False):
    agent_id: Required[str]

    name: Required[str]

    type: Required[
        Literal[
            "function",
            "integration",
            "system",
            "api_call",
            "computer_20241022",
            "text_editor_20241022",
            "bash_20241022",
        ]
    ]

    api_call: Optional[APICall]
    """API call definition"""

    bash_20241022: Optional[Bash20241022Def]

    computer_20241022: Optional[Computer20241022Def]
    """Anthropic new tools"""

    description: Optional[str]

    function: Optional[FunctionDef]
    """Function definition"""

    integration: Optional[Integration]
    """Brave integration definition"""

    system: Optional[SystemDef]
    """System definition"""

    text_editor_20241022: Optional[TextEditor20241022Def]


class APICallParamsSchemaProperties(TypedDict, total=False):
    type: Required[str]

    description: Optional[str]

    enum: Optional[List[str]]

    items: object


class APICallParamsSchema(TypedDict, total=False):
    properties: Required[Dict[str, APICallParamsSchemaProperties]]

    additional_properties: Annotated[Optional[bool], PropertyInfo(alias="additionalProperties")]

    required: List[str]

    type: str


class APICall(TypedDict, total=False):
    method: Required[Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]]

    url: Required[str]

    content: Optional[str]

    cookies: Optional[Dict[str, str]]

    data: Optional[object]

    files: Optional[object]

    follow_redirects: Optional[bool]

    headers: Optional[Dict[str, str]]

    include_response_content: bool

    json: Optional[object]

    params: Union[str, object, None]

    params_schema: Optional[APICallParamsSchema]
    """JSON Schema for API call parameters"""

    schema: Optional[object]

    secrets: Optional[Dict[str, SecretRef]]

    timeout: Optional[int]


Integration: TypeAlias = Union[
    DummyIntegrationDef,
    BraveIntegrationDef,
    EmailIntegrationDef,
    SpiderIntegrationDef,
    WikipediaIntegrationDef,
    WeatherIntegrationDef,
    MailgunIntegrationDef,
    BrowserbaseContextIntegrationDef,
    BrowserbaseExtensionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionIntegrationDef,
    BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef,
    RemoteBrowserIntegrationDef,
    LlamaParseIntegrationDef,
    FfmpegIntegrationDef,
    CloudinaryUploadIntegrationDef,
    CloudinaryEditIntegrationDef,
    ArxivIntegrationDef,
    UnstructuredIntegrationDef,
    AlgoliaIntegrationDef,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ..._models import BaseModel
from ..shared.doc_reference import DocReference

__all__ = ["DocSearchResponse"]


class DocSearchResponse(BaseModel):
    docs: List[DocReference]

    time: float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["SystemDef"]


class SystemDef(TypedDict, total=False):
    operation: Required[
        Literal[
            "create",
            "update",
            "patch",
            "create_or_update",
            "embed",
            "change_status",
            "search",
            "chat",
            "history",
            "delete",
            "get",
            "list",
        ]
    ]

    resource: Required[Literal["agent", "user", "task", "execution", "doc", "session", "job"]]

    arguments: Optional[object]

    resource_id: Optional[str]

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import TYPE_CHECKING, Union, Iterable, Optional
from typing_extensions import Literal, Required, TypeAlias, TypedDict, TypeAliasType

from ..._compat import PYDANTIC_V2
from ..get_step_param import GetStepParam
from ..log_step_param import LogStepParam
from ..set_step_param import SetStepParam
from ..sleep_step_param import SleepStepParam
from ..yield_step_param import YieldStepParam
from .prompt_step_input import PromptStepInput
from ..return_step_param import ReturnStepParam
from ..evaluate_step_param import EvaluateStepParam
from ..tool_call_step_param import ToolCallStepParam
from ..error_workflow_step_param import ErrorWorkflowStepParam
from ..wait_for_input_step_param import WaitForInputStepParam

__all__ = [
    "IfElseStepInput",
    "Then",
    "ThenSwitchStepInput",
    "ThenSwitchStepInputSwitch",
    "ThenSwitchStepInputSwitchThen",
    "ThenForeachStepInput",
    "ThenForeachStepInputForeach",
    "ThenForeachStepInputForeachDo",
    "ThenParallelStepInput",
    "ThenParallelStepInputParallel",
    "ThenThenInput",
    "ThenThenInputMap",
    "Else",
    "ElseSwitchStepInput",
    "ElseSwitchStepInputSwitch",
    "ElseSwitchStepInputSwitchThen",
    "ElseForeachStepInput",
    "ElseForeachStepInputForeach",
    "ElseForeachStepInputForeachDo",
    "ElseParallelStepInput",
    "ElseParallelStepInputParallel",
    "ElseElseInput",
    "ElseElseInputMap",
]

ThenSwitchStepInputSwitchThen: TypeAlias = Union[
    EvaluateStepParam,
    ToolCallStepParam,
    PromptStepInput,
    GetStepParam,
    SetStepParam,
    LogStepParam,
    YieldStepParam,
    ReturnStepParam,
    SleepStepParam,
    ErrorWorkflowStepParam,
    WaitForInputStepParam,
]


class ThenSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[ThenSwitchStepInputSwitchThen]


class ThenSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[ThenSwitchStepInputSwitch]]

    label: Optional[str]


ThenForeachStepInputForeachDo: TypeAlias = Union[
    WaitForInputStepParam,
    EvaluateStepParam,
    ToolCallStepParam,
    PromptStepInput,
    GetStepParam,
    SetStepParam,
    LogStepParam,
    YieldStepParam,
]

_ThenForeachStepInputForeachReservedKeywords = TypedDict(
    "_ThenForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class ThenForeachStepInputForeach(_ThenForeachStepInputForeachReservedKeywords, total=False):
    do: Required[ThenForeachStepInputForeachDo]


class ThenForeachStepInput(TypedDict, total=False):
    foreach: Required[ThenForeachStepInputForeach]

    label: Optional[str]


ThenParallelStepInputParallel: TypeAlias = Union[
    EvaluateStepParam, ToolCallStepParam, PromptStepInput, GetStepParam, SetStepParam, LogStepParam, YieldStepParam
]


class ThenParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[ThenParallelStepInputParallel]]

    label: Optional[str]


ThenThenInputMap: TypeAlias = Union[
    EvaluateStepParam, ToolCallStepParam, PromptStepInput, GetStepParam, SetStepParam, LogStepParam, YieldStepParam
]


class ThenThenInput(TypedDict, total=False):
    map: Required[ThenThenInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


if TYPE_CHECKING or PYDANTIC_V2:
    Then = TypeAliasType(
        "Then",
        Union[
            WaitForInputStepParam,
            EvaluateStepParam,
            ToolCallStepParam,
            PromptStepInput,
            GetStepParam,
            SetStepParam,
            LogStepParam,
            YieldStepParam,
            ReturnStepParam,
            SleepStepParam,
            ErrorWorkflowStepParam,
            "IfElseStepInput",
            ThenSwitchStepInput,
            ThenForeachStepInput,
            ThenParallelStepInput,
            ThenThenInput,
        ],
    )
else:
    Then: TypeAlias = Union[
        WaitForInputStepParam,
        EvaluateStepParam,
        ToolCallStepParam,
        PromptStepInput,
        GetStepParam,
        SetStepParam,
        LogStepParam,
        YieldStepParam,
        ReturnStepParam,
        SleepStepParam,
        ErrorWorkflowStepParam,
        "IfElseStepInput",
        ThenSwitchStepInput,
        ThenForeachStepInput,
        ThenParallelStepInput,
        ThenThenInput,
    ]

ElseSwitchStepInputSwitchThen: TypeAlias = Union[
    EvaluateStepParam,
    ToolCallStepParam,
    PromptStepInput,
    GetStepParam,
    SetStepParam,
    LogStepParam,
    YieldStepParam,
    ReturnStepParam,
    SleepStepParam,
    ErrorWorkflowStepParam,
    WaitForInputStepParam,
]


class ElseSwitchStepInputSwitch(TypedDict, total=False):
    case: Required[Literal["_"]]

    then: Required[ElseSwitchStepInputSwitchThen]


class ElseSwitchStepInput(TypedDict, total=False):
    switch: Required[Iterable[ElseSwitchStepInputSwitch]]

    label: Optional[str]


ElseForeachStepInputForeachDo: TypeAlias = Union[
    WaitForInputStepParam,
    EvaluateStepParam,
    ToolCallStepParam,
    PromptStepInput,
    GetStepParam,
    SetStepParam,
    LogStepParam,
    YieldStepParam,
]

_ElseForeachStepInputForeachReservedKeywords = TypedDict(
    "_ElseForeachStepInputForeachReservedKeywords",
    {
        "in": str,
    },
    total=False,
)


class ElseForeachStepInputForeach(_ElseForeachStepInputForeachReservedKeywords, total=False):
    do: Required[ElseForeachStepInputForeachDo]


class ElseForeachStepInput(TypedDict, total=False):
    foreach: Required[ElseForeachStepInputForeach]

    label: Optional[str]


ElseParallelStepInputParallel: TypeAlias = Union[
    EvaluateStepParam, ToolCallStepParam, PromptStepInput, GetStepParam, SetStepParam, LogStepParam, YieldStepParam
]


class ElseParallelStepInput(TypedDict, total=False):
    parallel: Required[Iterable[ElseParallelStepInputParallel]]

    label: Optional[str]


ElseElseInputMap: TypeAlias = Union[
    EvaluateStepParam, ToolCallStepParam, PromptStepInput, GetStepParam, SetStepParam, LogStepParam, YieldStepParam
]


class ElseElseInput(TypedDict, total=False):
    map: Required[ElseElseInputMap]

    over: Required[str]

    initial: object

    label: Optional[str]

    parallelism: Optional[int]

    reduce: Optional[str]


if TYPE_CHECKING or PYDANTIC_V2:
    Else = TypeAliasType(
        "Else",
        Union[
            WaitForInputStepParam,
            EvaluateStepParam,
            ToolCallStepParam,
            PromptStepInput,
            GetStepParam,
            SetStepParam,
            LogStepParam,
            YieldStepParam,
            ReturnStepParam,
            SleepStepParam,
            ErrorWorkflowStepParam,
            "IfElseStepInput",
            ElseSwitchStepInput,
            ElseForeachStepInput,
            ElseParallelStepInput,
            ElseElseInput,
        ],
    )
else:
    Else: TypeAlias = Union[
        WaitForInputStepParam,
        EvaluateStepParam,
        ToolCallStepParam,
        PromptStepInput,
        GetStepParam,
        SetStepParam,
        LogStepParam,
        YieldStepParam,
        ReturnStepParam,
        SleepStepParam,
        ErrorWorkflowStepParam,
        "IfElseStepInput",
        ElseSwitchStepInput,
        ElseForeachStepInput,
        ElseParallelStepInput,
        ElseElseInput,
    ]

_IfElseStepInputReservedKeywords = TypedDict(
    "_IfElseStepInputReservedKeywords",
    {
        "if": str,
        "else": Optional[Else],
    },
    total=False,
)


class IfElseStepInput(_IfElseStepInputReservedKeywords, total=False):
    then: Required[Then]
    """The steps to run if the condition is true"""

    label: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["CloudinarySetup"]


class CloudinarySetup(TypedDict, total=False):
    cloudinary_api_key: Required[str]

    cloudinary_api_secret: Required[str]

    cloudinary_cloud_name: Required[str]

    params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ArxivSearchArguments"]


class ArxivSearchArguments(TypedDict, total=False):
    query: Required[str]

    download_pdf: bool

    id_list: Optional[List[str]]

    max_results: int

    sort_by: Literal["relevance", "lastUpdatedDate", "submittedDate"]

    sort_order: Literal["ascending", "descending"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable, Optional
from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["BrowserbaseCreateSessionArguments"]


class BrowserbaseCreateSessionArguments(TypedDict, total=False):
    browser_settings: Annotated[object, PropertyInfo(alias="browserSettings")]

    extension_id: Annotated[Optional[str], PropertyInfo(alias="extensionId")]

    keep_alive: Annotated[bool, PropertyInfo(alias="keepAlive")]

    project_id: Annotated[Optional[str], PropertyInfo(alias="projectId")]

    proxies: Union[bool, Iterable[object]]

    timeout: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["UnstructuredPartitionArguments"]


class UnstructuredPartitionArguments(TypedDict, total=False):
    file: Required[str]

    filename: Optional[str]

    partition_params: Optional[object]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["Computer20241022Def"]


class Computer20241022Def(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["EmailArguments"]

_EmailArgumentsReservedKeywords = TypedDict(
    "_EmailArgumentsReservedKeywords",
    {
        "from": str,
    },
    total=False,
)


class EmailArguments(_EmailArgumentsReservedKeywords, total=False):
    body: Required[str]

    subject: Required[str]

    to: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from .._models import BaseModel
from .log_prob_response import LogProbResponse
from .chosen_bash20241022 import ChosenBash20241022
from .chosen_function_call import ChosenFunctionCall
from .shared.doc_reference import DocReference
from .chosen_computer20241022 import ChosenComputer20241022
from .chosen_text_editor20241022 import ChosenTextEditor20241022

__all__ = [
    "ChatResponse",
    "Choice",
    "ChoiceSingleChatOutput",
    "ChoiceSingleChatOutputMessage",
    "ChoiceSingleChatOutputMessageContentUnionMember2",
    "ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1",
    "ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source",
    "ChoiceSingleChatOutputMessageToolCall",
    "ChoiceSingleChatOutputToolCall",
    "ChoiceMultipleChatOutput",
    "ChoiceMultipleChatOutputMessage",
    "ChoiceMultipleChatOutputMessageContentUnionMember2",
    "ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1",
    "ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source",
    "ChoiceMultipleChatOutputMessageToolCall",
    "ChoiceMultipleChatOutputToolCall",
    "Usage",
]


class ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7(BaseModel):
    image_url: ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7ImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1(BaseModel):
    source: ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4(BaseModel):
    content: Union[
        List[ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0],
        List[ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


ChoiceSingleChatOutputMessageContentUnionMember2: TypeAlias = Union[
    ChoiceSingleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3,
    ChoiceSingleChatOutputMessageContentUnionMember2ContentModel7,
    ChoiceSingleChatOutputMessageContentUnionMember2ContentModel4,
]

ChoiceSingleChatOutputMessageToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class ChoiceSingleChatOutputMessage(BaseModel):
    role: Literal["user", "assistant", "system", "tool"]

    id: Optional[str] = None

    content: Union[str, List[str], List[ChoiceSingleChatOutputMessageContentUnionMember2], None] = None

    created_at: Optional[datetime] = None

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[ChoiceSingleChatOutputMessageToolCall]] = None


ChoiceSingleChatOutputToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class ChoiceSingleChatOutput(BaseModel):
    index: int

    message: ChoiceSingleChatOutputMessage

    finish_reason: Optional[Literal["stop", "length", "content_filter", "tool_calls"]] = None

    logprobs: Optional[LogProbResponse] = None

    tool_calls: Optional[List[ChoiceSingleChatOutputToolCall]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7(BaseModel):
    image_url: ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7ImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1(BaseModel):
    source: ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4(BaseModel):
    content: Union[
        List[ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember0],
        List[ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4ContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


ChoiceMultipleChatOutputMessageContentUnionMember2: TypeAlias = Union[
    ChoiceMultipleChatOutputMessageContentUnionMember2AgentsAPIAutogenChatContentModel3,
    ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel7,
    ChoiceMultipleChatOutputMessageContentUnionMember2ContentModel4,
]

ChoiceMultipleChatOutputMessageToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class ChoiceMultipleChatOutputMessage(BaseModel):
    role: Literal["user", "assistant", "system", "tool"]

    id: Optional[str] = None

    content: Union[str, List[str], List[ChoiceMultipleChatOutputMessageContentUnionMember2], None] = None

    created_at: Optional[datetime] = None

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[ChoiceMultipleChatOutputMessageToolCall]] = None


ChoiceMultipleChatOutputToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class ChoiceMultipleChatOutput(BaseModel):
    index: int

    messages: List[ChoiceMultipleChatOutputMessage]

    finish_reason: Optional[Literal["stop", "length", "content_filter", "tool_calls"]] = None

    logprobs: Optional[LogProbResponse] = None

    tool_calls: Optional[List[ChoiceMultipleChatOutputToolCall]] = None


Choice: TypeAlias = Union[ChoiceSingleChatOutput, ChoiceMultipleChatOutput]


class Usage(BaseModel):
    completion_tokens: Optional[int] = None

    prompt_tokens: Optional[int] = None

    total_tokens: Optional[int] = None


class ChatResponse(BaseModel):
    id: str

    choices: List[Choice]

    created_at: datetime

    docs: Optional[List[DocReference]] = None

    jobs: Optional[List[str]] = None

    usage: Optional[Usage] = None
    """Usage statistics for the completion request"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["BrowserbaseListSessionsArguments"]


class BrowserbaseListSessionsArguments(BaseModel):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["CloudinaryUploadArguments"]


class CloudinaryUploadArguments(BaseModel):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .secret_ref import SecretRef
from .system_def import SystemDef
from .function_def import FunctionDef
from .bash20241022_def import Bash20241022Def
from .named_tool_choice import NamedToolChoice
from ..chosen_bash20241022 import ChosenBash20241022
from .computer20241022_def import Computer20241022Def
from ..chosen_function_call import ChosenFunctionCall
from .arxiv_integration_def import ArxivIntegrationDef
from .brave_integration_def import BraveIntegrationDef
from .dummy_integration_def import DummyIntegrationDef
from .email_integration_def import EmailIntegrationDef
from .ffmpeg_integration_def import FfmpegIntegrationDef
from .spider_integration_def import SpiderIntegrationDef
from .algolia_integration_def import AlgoliaIntegrationDef
from .mailgun_integration_def import MailgunIntegrationDef
from .text_editor20241022_def import TextEditor20241022Def
from .weather_integration_def import WeatherIntegrationDef
from ..chosen_computer20241022 import ChosenComputer20241022
from .wikipedia_integration_def import WikipediaIntegrationDef
from ..chosen_text_editor20241022 import ChosenTextEditor20241022
from .llama_parse_integration_def import LlamaParseIntegrationDef
from .unstructured_integration_def import UnstructuredIntegrationDef
from .remote_browser_integration_def import RemoteBrowserIntegrationDef
from .cloudinary_edit_integration_def import CloudinaryEditIntegrationDef
from .cloudinary_upload_integration_def import CloudinaryUploadIntegrationDef
from .browserbase_context_integration_def import BrowserbaseContextIntegrationDef
from .browserbase_extension_integration_def import BrowserbaseExtensionIntegrationDef
from .browserbase_get_session_integration_def import BrowserbaseGetSessionIntegrationDef
from .browserbase_list_sessions_integration_def import BrowserbaseListSessionsIntegrationDef
from .browserbase_create_session_integration_def import BrowserbaseCreateSessionIntegrationDef
from .browserbase_complete_session_integration_def import BrowserbaseCompleteSessionIntegrationDef
from .browserbase_get_session_live_urls_integration_def import BrowserbaseGetSessionLiveURLsIntegrationDef

__all__ = [
    "PromptStepInput",
    "PromptUnionMember0",
    "PromptUnionMember0ContentUnionMember1",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "PromptUnionMember0ContentUnionMember1ContentModel1Input",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1",
    "PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source",
    "PromptUnionMember0ToolCall",
    "ToolChoice",
    "ToolsUnionMember1",
    "ToolsUnionMember1ToolRef",
    "ToolsUnionMember1ToolRefRef",
    "ToolsUnionMember1ToolRefRefToolRefByID",
    "ToolsUnionMember1ToolRefRefToolRefByName",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties",
    "ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration",
]


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(BaseModel):
    image_url: PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source(BaseModel):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1(BaseModel):
    source: PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class PromptUnionMember0ContentUnionMember1ContentModel1Input(BaseModel):
    content: Union[
        List[PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember0],
        List[PromptUnionMember0ContentUnionMember1ContentModel1InputContentUnionMember1],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


PromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContent,
    PromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    PromptUnionMember0ContentUnionMember1ContentModel1Input,
]

PromptUnionMember0ToolCall: TypeAlias = Union[
    ChosenFunctionCall, ChosenComputer20241022, ChosenTextEditor20241022, ChosenBash20241022
]


class PromptUnionMember0(BaseModel):
    content: Union[List[str], List[PromptUnionMember0ContentUnionMember1], str, None] = None

    role: Literal["user", "assistant", "system", "tool"]

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[PromptUnionMember0ToolCall]] = None


ToolChoice: TypeAlias = Union[Literal["auto", "none"], NamedToolChoice, None]


class ToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class ToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


ToolsUnionMember1ToolRefRef: TypeAlias = Union[
    ToolsUnionMember1ToolRefRefToolRefByID, ToolsUnionMember1ToolRefRefToolRefByName
]


class ToolsUnionMember1ToolRef(BaseModel):
    ref: ToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties(BaseModel):
    type: str

    description: Optional[str] = None

    enum: Optional[List[str]] = None

    items: Optional[object] = None


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema(BaseModel):
    properties: Dict[str, ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchemaProperties]

    additional_properties: Optional[bool] = FieldInfo(alias="additionalProperties", default=None)

    required: Optional[List[str]] = None

    type: Optional[str] = None


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    include_response_content: Optional[bool] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    params_schema: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICallParamsSchema] = None
    """JSON Schema for API call parameters"""

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    secrets: Optional[Dict[str, SecretRef]] = None

    timeout: Optional[int] = None


ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration: TypeAlias = Union[
    DummyIntegrationDef,
    BraveIntegrationDef,
    EmailIntegrationDef,
    SpiderIntegrationDef,
    WikipediaIntegrationDef,
    WeatherIntegrationDef,
    MailgunIntegrationDef,
    BrowserbaseContextIntegrationDef,
    BrowserbaseExtensionIntegrationDef,
    BrowserbaseListSessionsIntegrationDef,
    BrowserbaseCreateSessionIntegrationDef,
    BrowserbaseGetSessionIntegrationDef,
    BrowserbaseCompleteSessionIntegrationDef,
    BrowserbaseGetSessionLiveURLsIntegrationDef,
    RemoteBrowserIntegrationDef,
    LlamaParseIntegrationDef,
    FfmpegIntegrationDef,
    CloudinaryUploadIntegrationDef,
    CloudinaryEditIntegrationDef,
    ArxivIntegrationDef,
    UnstructuredIntegrationDef,
    AlgoliaIntegrationDef,
    None,
]


class ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputAPICall] = None
    """API call definition"""

    bash_20241022: Optional[Bash20241022Def] = None

    computer_20241022: Optional[Computer20241022Def] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[FunctionDef] = None
    """Function definition"""

    integration: Optional[ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInputIntegration] = None
    """Brave integration definition"""

    system: Optional[SystemDef] = None
    """System definition"""

    text_editor_20241022: Optional[TextEditor20241022Def] = None


ToolsUnionMember1: TypeAlias = Union[
    ToolsUnionMember1ToolRef, ToolsUnionMember1AgentsAPIAutogenToolsCreateToolRequestInput
]


class PromptStepInput(BaseModel):
    prompt: Union[List[PromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[ToolChoice] = None

    tools: Union[Literal["all"], List[ToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["UnstructuredPartitionArguments"]


class UnstructuredPartitionArguments(BaseModel):
    file: str

    filename: Optional[str] = None

    partition_params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["LlamaParseSetup"]


class LlamaParseSetup(BaseModel):
    llamaparse_api_key: str

    params: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal, TypeAlias, TypedDict

from .hybrid_doc_search_param import HybridDocSearchParam
from .vector_doc_search_param import VectorDocSearchParam
from .text_only_doc_search_param import TextOnlyDocSearchParam

__all__ = ["SessionResetParams", "RecallOptions"]


class SessionResetParams(TypedDict, total=False):
    auto_run_tools: bool

    context_overflow: Optional[Literal["truncate", "adaptive"]]

    forward_tool_calls: bool

    metadata: Optional[object]

    recall_options: Optional[RecallOptions]

    render_templates: bool

    situation: Optional[str]

    system_template: Optional[str]

    token_budget: Optional[int]


RecallOptions: TypeAlias = Union[VectorDocSearchParam, TextOnlyDocSearchParam, HybridDocSearchParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["RemoteBrowserSetup"]


class RemoteBrowserSetup(TypedDict, total=False):
    connect_url: Optional[str]

    height: Optional[int]

    width: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .token_log_prob import TokenLogProb

__all__ = ["LogProbResponse"]


class LogProbResponse(BaseModel):
    content: Optional[List[TokenLogProb]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["AlgoliaSearchArguments"]


class AlgoliaSearchArguments(BaseModel):
    index_name: str

    query: str

    attributes_to_retrieve: Optional[List[str]] = None

    hits_per_page: Optional[int] = None
